"""A module providing information on build-time configuration of pacemaker."""

__all__ = ["BuildOptions"]
__copyright__ = "Copyright 2023-2024 the Pacemaker project contributors"
__license__ = "GNU Lesser General Public License version 2.1 or later (LGPLv2.1+)"


class BuildOptions:
    """
    Variables generated as part of the ./configure && make process.

    These affect how pacemaker was configured and where its various parts
    get installed.
    """

    BASH_PATH = "/usr/bin/bash"
    """Path to the bash shell."""

    _BUILD_DIR = "/builddir/build/BUILD/pacemaker-0f6499026"
    """
    Top-level build directory.

    NOTE: This is not especially useful on installed systems, but is useful for
    running various programs from a source checkout
    """

    CIB_DIR = "/var/lib/pacemaker/cib"
    """Where CIB files are stored."""

    CIB_SCHEMA_VERSION = "4.0"
    """Latest supported CIB schema version number."""

    COROSYNC_CONFIG_FILE = "/etc/corosync/corosync.conf"
    """Path to the corosync config file."""

    DAEMON_DIR = "/usr/libexec/pacemaker"
    """Where Pacemaker daemons are installed."""

    DAEMON_USER = "hacluster"
    """User to run Pacemaker daemons as."""

    DATA_DIR = "/usr/share"
    """Where read-only architecture-independent data is stored."""

    _FENCE_BINDIR = "/usr/sbin"
    """Where executable fence agents are installed."""

    # pylint: disable-msg=using-constant-test
    INIT_DIR = "/etc/rc.d/init.d" if "/etc/rc.d/init.d" else None
    """Where LSB init scripts are stored."""

    LIBEXEC_DIR = "/usr/libexec"
    """Where programs started by other programs are stored."""

    LOCAL_STATE_DIR = "/var"
    """Where miscellaneous temporary state files are stored."""

    LOG_DIR = "/var/log/pacemaker"
    """Where Pacemaker log files are stored."""

    OCF_RA_INSTALL_DIR = "/usr/lib/ocf/resource.d"
    """Where resource agents are installed."""

    OCF_ROOT_DIR = "/usr/lib/ocf"
    """Root directory for OCF resource agents and libraries."""

    RSC_TMP_DIR = "/run/resource-agents"
    """Where resource agents should keep state files."""

    REMOTE_ENABLED = True
    """True if Pacemaker Remote support is enabled."""

    RUNTIME_STATE_DIR = "/run"
    """Where runtime data is stored."""

    SBIN_DIR = "/usr/sbin"
    """Where administrative programs are installed."""

    SCHEMA_DIR = "/usr/share/pacemaker"
    """Where Relax-NG schema files are stored."""

    UNIT_DIR = "/usr/lib/systemd/system"
    """Where system-wide systemd unit files are stored."""

    XMLLINT_PATH = "/usr/bin/xmllint"
    """Path to the xmllint program."""
